# Intermediate Representation for LLM Histories
This repository provides the core types for a standardized way to represent messages for LLMs. Additional chunk-types will be added in the future.

## Installation via Pypi:

```bash
pip install llm-ir
```

## Imports:

```python
from llm_ir import AIMessage, AIRoles, AIChunk, AIChunkText, AIChunkFile
```
